JITDylibRef

Struct JITDylibRef 

pub struct JITDylibRef {
    dylib: NonNull<LLVMOrcOpaqueJITDylib>,
}
A JIT dynamic library reference.

JITDylibs provide the symbol tables.

Fields

dylib: NonNull<LLVMOrcOpaqueJITDylib>

Implementations

Source

impl JITDylibRef

pub unsafe fn from_inner(dylib: LLVMOrcJITDylibRef) -> Option<Self>

Wraps a raw pointer.

pub unsafe fn from_inner_unchecked(dylib: LLVMOrcJITDylibRef) -> Self

Wraps a raw pointer. Must not be null.

pub fn as_inner(self) -> LLVMOrcJITDylibRef

Unwraps the raw pointer.

pub fn create_resource_tracker(self) -> ResourceTracker

Return a reference to a newly created resource tracker associated with JD.

pub fn get_default_resource_tracker(self) -> ResourceTracker

Return a reference to the default resource tracker for the given JITDylib.

pub fn define( self, mu: MaterializationUnit, ) -> Result<(), (LLVMString, MaterializationUnit)>

Add the given MaterializationUnit to the given JITDylib.

Add another JITDylib to this JITDylib’s link order.

Symbols not found in this JITDylib will be searched for in other.

pub fn clear(self) -> Result<(), LLVMString>

Calls remove on all trackers associated with this JITDylib.

pub fn add_generator(self, dg: DefinitionGenerator)

Add a DefinitionGenerator to the given JITDylib.